# Basic forms of gauge function
#===============================

gauge_rvad<-function(xy,par)
{
  x<-xy[1];y<-xy[2]
  max(x,y)/par +min(x,y)*(1-1/par)
}

gauge_gaussian<-function(xy,par)
{
  x<-xy[1];y<-xy[2]
  (x+y-2*par*sqrt(x*y))/(1-par^2)
}

gauge_invlogistic<-function(xy,par)
{
  x<-xy[1];y<-xy[2]
  (x^par+y^par)^(1/par)
}

gauge_square<-function(xy,par)
{
  x<-xy[1];y<-xy[2]
  max((x-y)/par,(y-x)/par,(x+y)/(2-par))
}

gauge_2comp<-function(xy,par)
{
  x<-xy[1];y<-xy[2]
  max((x-y)/par[1],(y-x)/par[1],min((y-par[2]*x)/(1-par[1]-par[2]),(x-par[2]*y)/(1-par[1]-par[2])))
}


# Functions for mixing gauge functions additively and rescaling them to represent exponential margins
#====================================================================================================

# additivegauge.scaling and additivegauge.rescale allow for mixing two gauges additively;
# this could be extended in future

# The output of additivegauge.scaling, ms (stands for "maxscale"), is the amount to scale
# each margin by in order to get the additive gauge to be appropriately scaled for exponential margins

#====================================================================================================

additivegauge.scaling<-function(gauge1,gauge2,par1,par2,weight)
{
  dummy<-function(xy)
  {
    gauge1(xy,par=par1) + weight*gauge2(xy,par=par2)
  }
  wseq1<-seq(0,1,len=1000)
  ms<-max(wseq1/apply(cbind(wseq1,1-wseq1),1,dummy))
  return(ms)
}

# ms is used as input in additivegauge.rescale to get the rescaled gauge function

additivegauge.rescale<-function(xy,gauge1,gauge2,par1,par2,weight,ms)
{
  return(gauge1(ms*xy,par=par1) + weight*gauge2(ms*xy,par=par2))
}
